@@ -7,20 +7,17 @@ import lldb
 
 from hilda.hilda_client import HildaClient
 
-coloredlogs.install(level=logging.DEBUG)
-logging.getLogger('asyncio').disabled = True
-logging.getLogger('parso.cache').disabled = True
-logging.getLogger('parso.cache.pickle').disabled = True
-logging.getLogger('parso.python.diff').disabled = True
-logging.getLogger('humanfriendly.prompts').disabled = True
-
 lldb.hilda_client = None
 
 
 def hilda(debugger, command, result, internal_dict):
+    coloredlogs.install(level=logging.DEBUG)
+
     if lldb.hilda_client is None:
         lldb.hilda_client = HildaClient(debugger)
-    lldb.hilda_client.interactive()
+
+    additional_namespace = {'ui': lldb.hilda_client.ui_manager}
+    lldb.hilda_client.interact(additional_namespace=additional_namespace)
 
 
 def __lldb_init_module(debugger, internal_dict):
